@@ -13,10 +13,11 @@ This is for testing only. Yes, you read me, for TESTING. Didn't you hear me say?
 
 sub new {
 	my $class = shift;
-	my $self = $class->SUPER::new(@_, 'ToolPanel');
+	my $self = $class->SUPER::new(@_, 'SideBars');
 	return unless defined $self;
-	my $tp = $self->extGet('ToolPanel');
-	my $page = $tp->addPage('Seasons', 'view-list-details', undef, 'Select a season');
+	my $sb = $self->extGet('SideBars');
+	$sb->nbAdd('tool panel', 'RIGHT', 'right') unless $sb->nbExists('tool panel');
+	my $page = $sb->pageAdd('tool panel', 'Seasons', 'view-list-details', undef, 'Select a season');
 	$page->Label(-text => 'Seasons')->pack(-expand => 1, -fill => 'both');
 	$self->jobStart('jobtest', 'JobTest', $self);
 	return $self;
@@ -28,7 +29,8 @@ sub JobTest {
 
 sub Unload {
 	my $self = shift;
-	$self->extGet('ToolPanel')->deletePage('Seasons');
+	my $sb = $self->extGet('SideBars');
+	$sb->pageDelete('tool panel', 'Seasons');
 	return $self->SUPER::Unload
 }
 1;
